# Vertez

Vertez is a cutting-edge open-source framework dedicated to developing powerful and versatile libraries for statistical analysis, machine learning, and deep learning. We empower data scientists, researchers, and developers with a comprehensive suite of tools to drive insights and innovations in diverse domains.

At Vertez, we believe in democratizing access to advanced statistical techniques and the latest advancements in artificial intelligence. Our libraries provide an intuitive and flexible platform for statistical modeling, predictive analytics, and complex data-driven decision making. With a focus on simplicity, performance, and scalability, we enable practitioners to efficiently explore, analyze, and infer from their data.

Sponsor my project here: [![Sponsor](https://img.shields.io/badge/Sponsor-Donate-blue.svg)](https://github.com/sponsors/ravinthiranpartheepan1407)

## Vertez - Where Math and Data Science Create a Tapestry of Insights
<a href="https://a.co/d/iVHsqgE">
  <img src="https://images.spr.so/cdn-cgi/imagedelivery/j42No7y-dcokJuNgXeA0ig/9d0bd39a-1afb-4c2c-8c99-0b56c03b7968/Amazon_Post/w=1920,quality=80" alt="Amazon Product Image">
</a>

Avaiable Functions:
-  Chebyshev Distance
-  Correlation
-  Cosine Similarity
-  Covariance
-  Entropy
-  Euclidean Distance
-  Gini Index
-  Hamming Code
-  Kmeans Clustering
-  Linear Regression: Least Square Metric
-  Log Transform
-  Mean Absolute Error
-  Manhattan Distance
-  Max
-  Mean
-  Median
-  Min
-  Minkowski Distance
-  Minmax
-  Mode
-  Mean Squared Error
-  Range
-  Root Mean Squared Error
-  R-Squared
-  Sample Covariance
-  Sample variance
-  Softmax
-  Standard Deviation
-  Variance
-  Z-Score
